@@ -1,4 +1,4 @@
-# copyright 2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2013-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -21,17 +21,18 @@ from cubicweb.predicates import one_line_rset, is_instance
 from cubicweb.web.action import Action
 
 
-
 class ExecutableCreateRunAction(Action):
-    __regid__ = 'processing.executable_create_run'
+    __regid__ = "processing.executable_create_run"
 
-    __select__ = one_line_rset() & is_instance('Executable')
+    __select__ = one_line_rset() & is_instance("Executable")
 
-    title = _('create a run from this executable')
-    category = 'mainactions'
+    title = _("create a run from this executable")
+    category = "mainactions"
 
     def url(self):
-        linkto = 'executable:%s:subject' % self.cw_rset.get_entity(0, 0).eid
-        return self._cw.vreg["etypes"].etype_class(
-            'Run').cw_create_url(self._cw, __linkto=linkto)
-
+        linkto = "executable:%s:subject" % self.cw_rset.get_entity(0, 0).eid
+        return (
+            self._cw.vreg["etypes"]
+            .etype_class("Run")
+            .cw_create_url(self._cw, __linkto=linkto)
+        )
