@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# copyright 2012 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2012-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -22,10 +22,10 @@ from cubicweb_wireit.views.mixins import WiringViewMixin
 
 
 class RunChainPrimaryView(WiringViewMixin, PrimaryView):
-    __select__ = PrimaryView.__select__ & is_instance('RunChain') & one_line_rset()
+    __select__ = PrimaryView.__select__ & is_instance("RunChain") & one_line_rset()
 
     def render_entity_attributes(self, entity):
-        if entity.wiring and '__nowireit' not in self._cw.form:
+        if entity.wiring and "__nowireit" not in self._cw.form:
             wiring = entity.wiring[0]
             self.setup_editor(wiring, wiring.language[0])
         else:
