@@ -1,4 +1,4 @@
-# copyright 2013 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2013-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -20,12 +20,12 @@ from cubicweb.server import hook
 
 
 class RunCompleteHook(hook.Hook):
-    __regid__ = 'processing.test.run.complete'
-    __select__ = hook.Hook.__select__ & on_fire_transition('Run', 'wft_run_run')
-    events =  ('after_add_entity',)
+    __regid__ = "processing.test.run.complete"
+    __select__ = hook.Hook.__select__ & on_fire_transition("Run", "wft_run_run")
+    events = ("after_add_entity",)
 
     def __call__(self):
         run = self.entity.for_entity
         # exec arbitrary python code if specified
         if run.exe.python_code:
-            run.set_ovalues(o=eval(run.exe.python_code, {'run': run}))
+            run.set_ovalues(o=eval(run.exe.python_code, {"run": run}))
